@@ -271,6 +271,9 @@ PrimitiveTypeCoercion <- c("string" = "as.character",
                            "static_string" = "as.character",
                            "int" = "as.integer",
                            "uint" = "as.integer",
+                           "gint" = "as.integer",
+                           "guint" = "as.numeric",
+                           "guint32" = "as.numeric",                                                      
                            "float" = "as.numeric",
                            "bool" = "as.logical"
                            )
@@ -535,17 +538,20 @@ function(name, type, defs)
  nullOk <- FALSE
  if(length(type) > 1 && type[[2]] == "null-ok")
    nullOk <- TRUE
+
+ if(is.list(type))
+   type <- type[[1]]
  
  type <- type[1]
  
  name <- paste("s", name, sep="_")
  if(type == "string") {
     paste("CHAR_DEREF( STRING_ELT(", name, ", 0))")
- } else if(type == "int" || type == "uint") {
+ } else if(type == "int" || type == "uint" || type == "gint") {
     paste("INTEGER_DATA(",name,")[0]")
  } else if(type == "bool") {
     paste("LOGICAL_DATA(",name,")[0]")
- }else if(type == "float" || type == "double") {
+ }else if(type == "float" || type == "double" || type == "guint" || type == "guint32") {
     paste("NUMERIC_DATA(",name,")[0]")
  } else if(isEnum(type, defs$enums) || isFlag(type, defs$flags)) {
     paste( "(", type, ")", "INTEGER_DATA(", name, ")[0]")
@@ -557,6 +563,10 @@ function(name, type, defs)
    if(is.list(type))
      type <- type[[1]]
 
+   if(type == "GtkMenuPositionFunc") {
+     cat("**** Matched", type, " to " , names(defs$classes)[k], "\n") 
+   }
+
      # looks like I hard coded the mapping here to catch the HTML as a single word
      # I think I have a function that preserves this now.
     if(type == "GtkHTMLEmbedded") {
@@ -573,7 +583,8 @@ function(name, type, defs)
 
    val
  } else {
-    paste("(",type,"* ) getPtrValue(", name,")")
+   # cat("**** Using default for ", type , "\n")
+    paste("(", getCType(type, defs) , ") getPtrValue(", name, ")")
  }
 }
 
@@ -617,11 +628,14 @@ getCType <-
   #
 function(type, defs)
 {
+ if(is.list(type))
+   type = type[[1]]
+ 
  type <- type[1]
  
- if(type == "GtkWidget") {
-   str <- paste(type,"*")
- } else if(type == "bool")
+ if(type == "GtkWidget") 
+   str <- paste(type, "*")
+ else if(type == "bool")
    str <- "Rboolean"
  else if (type == "uint")
    str <- "unsigned int"
@@ -639,8 +653,14 @@ function(type, defs)
    str <- type
  } else if(type == "string[]") {
    str <- "string *"
+ } else if(type == "guint" || type == "gint" || type == "guint32") {
+   str <- type
+ } else if(type == "string[]") {
+   str <- "string *"
+ } else if(is.character(type) && length(grep("Func$", type)) > 0) {
+   str <- type
  } else {
-   str <- paste(type,"*")
+   str <- paste(type, "*")
  }
 
  str
