@@ -25,3 +25,16 @@ S_gdk_window_get_size ( USER_OBJECT_ s_window)
 }
 
 
+
+USER_OBJECT_
+S_getGdkEventButtonX(USER_OBJECT_ s_obj)
+{
+  
+    GdkEventButton *obj = ( GdkEventButton * ) getPtrValue(s_obj) ;
+    USER_OBJECT_ _ans;
+
+    _ans = asRNumeric(obj->x);
+
+    return(_ans);
+}
+
